"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ECharts = exports.using = exports.name = void 0;
const koishi_1 = require("koishi");
const echarts_1 = require("echarts");
const echarts = __importStar(require("echarts"));
const path_1 = __importDefault(require("path"));
const fs = __importStar(require("fs"));
exports.name = "echarts";
const logger = new koishi_1.Logger(exports.name);
exports.using = ["canvas"];
class ECharts extends koishi_1.Service {
    async createChart(width = this.config.width, height = this.config.height, options, theme) {
        let _canvas = this.ctx.canvas.createCanvas(width, height);
        const defaultTextStyle = {
            fontFamily: this.ctx.canvas.getPresetFont(),
            fontSize: 18, // 字体大小
        };
        if (!options.textStyle) {
            options.textStyle = defaultTextStyle;
        }
        if (!options.animation) {
            options.animation = false;
        }
        let chart = (0, echarts_1.init)(_canvas, theme || this.config.defaultTheme);
        chart.setOption(options);
        return _canvas.toBuffer("image/png");
    }
    constructor(ctx, config) {
        super(ctx, "echarts");
        this.config = config;
        echarts.setPlatformAPI({
            createCanvas() {
                return ctx.canvas.createCanvas(32, 32);
            },
            loadImage(src, onload, onerror) {
                const img = new ctx.canvas.Image();
                // 必须要绑定 this context.
                img.onload = onload.bind(img);
                img.onerror = onerror.bind(img);
                img.src = Buffer.from(src, "base64");
                return img;
            },
        });
        const themesDir = path_1.default.resolve(ctx.baseDir, config.themesDir);
        fs.mkdirSync(themesDir, { recursive: true });
        const files = fs.readdirSync(themesDir);
        files.forEach((file) => {
            const filePath = path_1.default.join(themesDir, file);
            const fileStat = fs.statSync(filePath);
            // 检查文件是否为 JSON 文件
            if (fileStat.isFile() && path_1.default.extname(filePath) === ".json") {
                const themeName = path_1.default.basename(filePath, ".json"); // 获取文件名作为主题名称
                const themeContent = fs.readFileSync(filePath, "utf8");
                const themeObj = JSON.parse(themeContent);
                // 注册为 ECharts 主题
                echarts.registerTheme(themeName, themeObj);
                logger.success(`Theme "${themeName}" registered successfully!`);
            }
        });
        ctx
            .command("echarts")
            .option("width", "-w <wid:posint>")
            .option("height", "-t <hei:posint>")
            .action(async ({ options }, set) => {
            const buffer = await this.createChart(options.width, options.height, {
                title: {
                    text: "ECharts 演示",
                },
                tooltip: {},
                legend: {
                    data: ["销量"],
                },
                xAxis: {
                    data: ["衬衫", "羊毛衫", "雪纺衫", "裤子", "高跟鞋", "袜子"],
                },
                yAxis: {},
                series: [
                    {
                        name: "销量",
                        type: "bar",
                        data: [5, 20, 36, 10, 10, 20],
                    },
                ],
            });
            return koishi_1.h.image(buffer, "image/png");
        });
        logger.success("Echarts 启动成功。");
    }
}
exports.ECharts = ECharts;
koishi_1.Context.service("echarts", ECharts);
exports.default = ECharts;
(function (ECharts) {
    ECharts.Config = koishi_1.Schema.object({
        width: koishi_1.Schema.natural().description("Table default width").default(1000),
        height: koishi_1.Schema.natural().description("Table default height").default(700),
        themesDir: koishi_1.Schema.path({
            filters: ["directory"],
            allowCreate: true,
        })
            .description("Theme storage path")
            .default("node-rs/canvas/echarts"),
        defaultTheme: koishi_1.Schema.string()
            .default("light")
            .description("light/dark default, You need to install more [themes](https://echarts.apache.org/zh/theme-builder.html)(builder) for further customization."),
    }).i18n({
        zh: {
            width: "表格默认宽度",
            height: "表格默认高度",
            themesDir: "主题存放目录",
            defaultTheme: "未指定主题时的默认主题，内置只有 light/dark 两种，可以往主题文件夹放更多来使用。[主题工具](https://echarts.apache.org/zh/theme-builder.html) <- 可点",
        },
    });
})(ECharts || (exports.ECharts = ECharts = {}));
